@@ -26,6 +26,14 @@ sub init {
     return $self;
 }
 
+# XML::Atom::Feed::entries() returns undef when there are no entries,
+# instead of an empty list, but only when using XML::LibXML.
+sub entries {
+    my $self = shift;
+    my @entries = $self->SUPER::entries(@_);
+    return @entries ? @entries : ();
+}
+
 
 1;
 
@@ -55,6 +63,10 @@ Subclass of C<XML::Atom::Feed>.
 
 Returns the continuation string, if any is present.
 
+=head2 entries
+
+Fixes bug in C<XML::Atom::Feed::entries()>.
+
 =head1 SEE ALSO
 
 L<XML::Atom::Feed>
